The ``config`` folder contains configuration files which customize default **PyAutoLens**.

Files
-----

- ``general.yaml``: Customizes general visualization settings (e.g. the matplotlib backend).
- ``plots_search.yaml``: Customize which non-linear search figures are output during a model-fit.